<script>
<![CDATA[
  <#ViewVariables>
  var XMul = 1, YMul= 1;
  var gGraph;
  /* These are the default attributes. They will be overridden if the
     document's aspect ratio is "none". In that case, these values will resemble
     the screen coordinates of the SVG element. */
  var _iViewBoxX = 1000, _iViewBoxY = 1000;
  var _iToolBarAttachX, _iToolBarAttachY;
  var _bCustomAspectRatio = false;

  function bIsEmbedded()
  {
    return (typeof(bContainsSVG) == "function");
  }
  function bIsContextMenuAvailable()
  {
    return (typeof(printNode) != "undefined");
  }

  var goHost = bIsEmbedded() ? window : parent;
  try {
    if (!goHost.iSvgWidth || !goHost.iSvgHeight)
      goHost = null;
  }
  catch (e) {
    goHost = null;
  }

  function AppendStringToEndOfMenu(sString)
  {
    if (WeAreCurrentlyViewedFromWithinPortal() && (AreWeInPrintFrame() == false) && bIsContextMenuAvailable())
    {
      var sOldMenu = printNode(contextMenu.firstChild);
      var iPos = sOldMenu.indexOf('\u003C/menu\u003E');
      sOldMenu = sOldMenu.slice(0, iPos) + sString + '\u003C/menu\u003E';
      var newRoot = parseXML(sOldMenu, contextMenu).firstChild;
      contextMenu.replaceChild( newRoot, contextMenu.firstChild );
    }
  }
  function AppendToMenu(sItemName, sAction)
  {
    var sItem = '\u003Citem onactivate=\"' + sAction + '\"\u003E' + sItemName + '\u003C/item\u003E';
    AppendStringToEndOfMenu(sItem);
  }

  function RemoveFromMenu(sItem)
  {
    if (WeAreCurrentlyViewedFromWithinPortal() && (AreWeInPrintFrame() == false) && bIsContextMenuAvailable())
    {
      var sOldMenu = printNode(contextMenu.firstChild);
      sItem = '\u003Citem onactivate=\"' + sItem;
      var iPos = sOldMenu.indexOf(sItem);
      if (iPos > 0)
      {
        sOldMenu = sOldMenu.slice(0, iPos - 1) + '\u003C/menu\u003E';
        var newMenuRoot = parseXML(sOldMenu, contextMenu ).firstChild;
        contextMenu.replaceChild( newMenuRoot, contextMenu.firstChild );
      }
    }
  }

  function AreWeInPrintFrame()
  {
    try {
       return top.ThisIsAPrintFrame || goHost.ThisIsAPrintFrame ||
              goHost.bIsInPDFPrintFrame();
    }
    catch (e) {
      return false;
    }
  }
  
  function WeAreCurrentlyViewedFromWithinPortal()
  { 
    if ( goHost && goHost.WeAreCurrentlyViewedFromWithinPortal ) return true;

    try {
      if (top != self)
      {
        if (top.location.href.indexOf('QPRPORTAL') > -1)
        {
          return true;
        }
      }
      return false;
    }
    catch (e) {
      return false;
    }
  } 
  
  function WeAreCurrentlyInPrintFrame()
  { 
    if ( goHost && goHost.bIsInPDFPrintFrame && goHost.bIsInPDFPrintFrame() )
      return true;

    if (WeAreCurrentlyViewedFromWithinPortal())
    {
      if (AreWeInPrintFrame())
      {
        return true;
      }
    }
    return false;
  }
  
  function SetModelPositionToCenterOfScreen(X, Y)
  {
    panX = _iViewBoxX / 2 - X * scale;
    panY = _iViewBoxY / 2 - Y * scale;
    gGraph.setAttribute("transform", "translate(" + panX + ", " + panY + "), scale(" + scale + ")");
  }
  
  function CenterScreen()
  {
    var ModelCenterX = (iRightmostX + iLeftmostX) / 2;
    var ModelCenterY = (iBottommostY + iTopmostY) / 2;
    SetModelPositionToCenterOfScreen(ModelCenterX, ModelCenterY);
  }

  function FitToScreen()
  {
    var GraphWidth = (iRightmostX - iLeftmostX) / XMul;
    var GraphHeight = (iBottommostY - iTopmostY) / YMul;
    var ScreenWidth = goHost ? goHost.iSvgWidth() : _iViewBoxX;
    var ScreenHeight = goHost ? goHost.iSvgHeight() : _iViewBoxY;
    if ((ScreenWidth / GraphWidth) < (ScreenHeight / GraphHeight))
    {
      scale = 0.95 * ScreenWidth / GraphWidth;
    }
    else
    {
      scale = 0.95 * ScreenHeight / GraphHeight;
    }
    CenterScreen();
  }

  function CalculateCoordinateMultipliers()
  { 
    if ( !_bCustomAspectRatio ) {
      var iMul;
      var ScreenWidth = goHost ? goHost.iSvgWidth() : _iViewBoxX;
      var ScreenHeight = goHost ? goHost.iSvgHeight() : _iViewBoxY;
      if (ScreenWidth < ScreenHeight)
      {
        iMul = ScreenWidth;
      }
      else
      {
        iMul = ScreenHeight;
      }
      XMul = _iViewBoxX / iMul;
      YMul = _iViewBoxY / iMul;
    }
  } 

  function CalculateCustomViewport()
  {
    var iWidth = goHost ? goHost.iSvgWidth() : _iViewBoxX;
    var iHeight = goHost ? goHost.iSvgHeight() : _iViewBoxY;  

    // This most probably means that the Portal frameset isn't yet initialized.
    if ( iWidth == 0 || isNaN(iWidth) || iHeight == 0 || isNaN(iHeight) )
      return;

    _iViewBoxX = iWidth;
    _iViewBoxY = iHeight;
    document.rootElement.setAttribute('viewBox',
                                      '0 0 ' + iWidth + ' ' + iHeight);
  }

  function oGetAbsoluteCoordinatesFromEvent(oEvent) {
    if ( typeof(oEvent.pageX) !== 'undefined' && oEvent.pageX )
      oGetAbsoluteCoordinatesFromEvent =
        function(oEvent) {
          return { piX: oEvent.pageX, piY: oEvent.pageY };
        };
    else
      oGetAbsoluteCoordinatesFromEvent =
        function(oEvent) {
          return { piX: oEvent.clientX, piY: oEvent.clientY };
       };

    return oGetAbsoluteCoordinatesFromEvent(oEvent);
  }

  /* This is a workaround to Firefox SVG handler's annoying feature that
     sometimes prevents the user from dragging SVG objects */
  function PreventDefaultEventHandlers(oEvent) {
    if ( oEvent.preventDefault )
      try { oEvent.preventDefault(); } catch ( err ) {}
    if ( oEvent.stopPropagation )
      try { oEvent.stopPropagation() } catch ( err ) {}
  }

  gGraph = document.getElementById("graph");
  gGraph.setAttribute("visibility", "hidden");

  var DragMode = 0;
  var gToolBar;
  var origX = 0;
  var origY = 0;
  var ToolBarOrigX = 0;
  var ToolBarOrigY = 0;
  var ToolBarX = 800;
  var ToolBarY = 50;
  var ToolBarDragMode = 0;
  var DragMove = 0;

  function ZoomIn(amount)
  {
    var ModelXAtScreenCenter = -(panX - _iViewBoxX / 2) / scale;
    var ModelYAtScreenCenter = -(panY - _iViewBoxY / 2) / scale;
    scale *=amount;
    SetModelPositionToCenterOfScreen(ModelXAtScreenCenter, ModelYAtScreenCenter);
  }

  function ZoomOut(amount)
  {
    var ModelXAtScreenCenter = -(panX - _iViewBoxX / 2) / scale;
    var ModelYAtScreenCenter = -(panY - _iViewBoxY / 2) / scale;
    scale /=amount;
    SetModelPositionToCenterOfScreen(ModelXAtScreenCenter, ModelYAtScreenCenter);
  }

  function PanSvg(dX,dY)
  {
    panX+=dX;
    panY+=dY;
    gGraph.setAttribute("transform", "translate(" + panX + ", " + panY + "), scale(" + scale + ")");
  }

  function OriginalPanningPosition()
  {
    panX = OriginalpanX;
    panY = OriginalpanY;
    scale = Originalscale;
    gGraph.setAttribute("transform", "translate(" + panX + ", " + panY + "), scale(" + scale + ")");
  }

  function SwitchDragMode(evt, mode)
  {
    if (DragMove == 1)
    {
      DragMode = mode;
      if (DragMode == 1)
      {
        PreventDefaultEventHandlers(evt);

        origX = evt.screenX - panX;
        origY = evt.screenY - panY;
      }
      else
      {
        ToolBarDragMode = 0;
      }
    }

    /* If, for some reason, the toolbar has slipped from under the cursor,
       stop dragging it */
    if ( mode == 0 && ToolBarDragMode == 1 ) ToolBarDragMode = 0;
  }

  function SwitchToolBarDragMode(evt, mode)
  {
    ToolBarDragMode = mode;
    if (ToolBarDragMode == 1)
    {
      PreventDefaultEventHandlers(evt);

      if ( _bCustomAspectRatio ) {
        var oCoordinates = oGetAbsoluteCoordinatesFromEvent(evt);

        ToolBarOrigX = oCoordinates.piX - ToolBarX;
        ToolBarOrigY = oCoordinates.piY - ToolBarY;
      } else {
        ToolBarOrigX = (evt.screenX * XMul - ToolBarX);
        ToolBarOrigY = (evt.screenY * YMul - ToolBarY);
      }
    }
    else if ( _bCustomAspectRatio )
      AttachToolBar();
  }

  function ToolBarDrag(evt)
  {
    if (ToolBarDragMode == 1)
    {
      if ( _bCustomAspectRatio ) {
        var oCoordinates = oGetAbsoluteCoordinatesFromEvent(evt);

        ToolBarX = oCoordinates.piX - ToolBarOrigX;
        ToolBarY = oCoordinates.piY - ToolBarOrigY;

        gToolBar.setAttribute("transform",
                              "translate(" + ToolBarX + "," + ToolBarY + ")");
      } else {
        ToolBarX = (evt.screenX * XMul - ToolBarOrigX);
        ToolBarY = (evt.screenY * YMul - ToolBarOrigY);
        gToolBar.setAttribute("transform", "translate(" + ToolBarX + ", " + ToolBarY + ") scale(" + XMul + "," + YMul + ")");
      }
    }
  }

  function Drag(evt)
  {
    // This comes first to make sure that toolbar dragging doesn't lag
    ToolBarDrag(evt);

    if (DragMode == 1)
    {
      panX = evt.screenX - origX;
      panY = evt.screenY - origY;
      gGraph.setAttribute("transform", "translate(" + panX + ", " + panY + "), scale(" + scale + ")");
    }
  }

  function syncToolbar()
  {
    if ( _bCustomAspectRatio ) {
      var iWidth = goHost ? goHost.iSvgWidth() : _iViewBoxX;
      var iHeight = goHost ? goHost.iSvgHeight() : _iViewBoxY;

      ToolBarX = _iToolBarAttachX < 0 ? iWidth + _iToolBarAttachX :
                                        _iToolBarAttachX;
      ToolBarY = _iToolBarAttachY < 0 ? iHeight + _iToolBarAttachY :
                                        _iToolBarAttachY;

      gToolBar.setAttribute('transform',
                            'translate(' + ToolBarX + ',' + ToolBarY + ')');
    } else {
      var r = document.rootElement
      var x = (ToolBarX - r.currentTranslate.x);
      var y = (ToolBarY - r.currentTranslate.y);
      gToolBar.setAttribute( "transform", "translate(" + x + ", " + y + "), scale(" + XMul + "," + YMul + ")");
    }
  }

  /* Attach the toolbar to the nearest extremes of the screen. For example,
     if the toolbar is in the upper right corner, it will be attached to the
     negative X coordinate (right wall) and positive Y coordinate (upper wall.) */
  function AttachToolBar() {
    var iWidth = goHost ? goHost.iSvgWidth() : _iViewBoxX;
    var iHeight = goHost ? goHost.iSvgHeight() : _iViewBoxY;

    if ( ToolBarX < iWidth / 2 )  _iToolBarAttachX = ToolBarX;
    else                          _iToolBarAttachX = ToolBarX - iWidth;
    if ( ToolBarY < iHeight / 2 ) _iToolBarAttachY = ToolBarY;
    else                          _iToolBarAttachY = ToolBarY - iHeight;
  }

  function SwitchDragMove()
  {
    var cursorIcon = document.getElementById("cursorIcon");
    var iconUrl = cursorIcon.getAttribute("xlink:href");
    var selectIcon;
    var handIcon;
    if (iconUrl.indexOf("hand.png") > 0) {
      selectIcon = iconUrl.replace("hand.png", "select.png");
      handIcon = iconUrl;
    } else {
      selectIcon = iconUrl;
      handIcon = iconUrl.replace("select.png", "hand.png");
    }

    if (DragMove == 1) {
      DragMove = 0;
      gGraph.setAttribute("cursor", "auto");
      cursorIcon.setAttribute("xlink:href", handIcon);
    } else {
      DragMove = 1;
      gGraph.setAttribute("cursor", "move");
      cursorIcon.setAttribute("xlink:href", selectIcon);
    }
  }

  function SetInitialToolbarCoordinates()
  { 
    if ( _bCustomAspectRatio ) {
      // The upper right corner.
      _iToolBarAttachX = -130;
      _iToolBarAttachY = 20;
    } else {
      // Use the old kaboom algorithm to get the toolbar somewhere near the
      // upper right corner, if we're in luck.
      var iWidth = goHost ? goHost.iSvgWidth() : _iViewBoxX;
      var iHeight = goHost ? goHost.iSvgHeight() : _iViewBoxY;
      var xmul = 1000 / iWidth; 
      var ymul = 1000 / iHeight;
      if (iHeight > iWidth)
        ToolBarX = 1000 - 110 * xmul;
      else
        ToolBarX = 130 + iHeight / 4 + 500 * iWidth / iHeight
      ToolBarY = 20 * ymul;
      }
  }  

  function HideToolBarUntilNextReload()
  {
    gToolBar.setAttribute("visibility", "hidden");
    document.rootElement.setAttribute("zoomAndPan", "enable");
    document.rootElement.setAttribute("enableZoomAndPanControls", "false");
  } 
  
  var _OrigOnResizeFunc;
  var _bIsGraphLayoutView = <#IsGraphLayoutView true="true" false="false">;
  var _bIsToolbarShown = <#IsToolbarShown true="true" false="false">;
  var _bInitialized = false;
  var _bResizing = false;
  
  function OnResize(e)
  {
    if (!_bResizing) {
      _bResizing = true;
      try {
        if (goHost && goHost.OnPortalFramesResized)
          goHost.OnPortalFramesResized();
      } finally {
        _bResizing = false;
      }
    }

    if (_bCustomAspectRatio)
      CalculateCustomViewport();

    if (!_bIsGraphLayoutView) {
      CalculateCoordinateMultipliers();
      FitToScreen();
    }
    
    if (!_bInitialized) {
      if (_bIsToolbarShown)
        InitializeToolbar();
      gGraph.setAttribute("visibility", "visible");
      _bInitialized = true;
    }

    if (_bIsToolbarShown)
      syncToolbar();

    if (_OrigOnResizeFunc)
      _OrigOnResizeFunc(e);
  }
  
  function InitializeToolbar()
  {
    if (!WeAreCurrentlyInPrintFrame()) {
      document.rootElement.addEventListener( "SVGScroll", syncToolbar, false )
      document.rootElement.addEventListener( "SVGResize", syncToolbar, false )
      document.rootElement.addEventListener( "SVGZoom", syncToolbar, false )
      SetInitialToolbarCoordinates();
      gToolBar.setAttribute("visibility", "visible");
    }
  }

  if (_bIsToolbarShown) {
    gToolBar = document.getElementById("toolbar");
    gToolBar.setAttribute("visibility", "hidden");

    if (WeAreCurrentlyInPrintFrame())
      HideToolBarUntilNextReload()
  }
  
  if (!_bIsGraphLayoutView && WeAreCurrentlyViewedFromWithinPortal() && !AreWeInPrintFrame()) {
    <#InitializeContextMenu>
  }

  if (goHost && goHost.IEANY) {
    _OrigOnResizeFunc = window.onresize;
    window.onresize = OnResize;
  }
  // prevent image bouncing on iPad when viewed outside Portal
  else if (goHost && !(goHost.IPAD && goHost.bInPortal && !goHost.bInPortal()))
    window.addEventListener("resize", OnResize, false);

  var oAttribute = document.rootElement.getAttribute('preserveAspectRatio');
  if (oAttribute && oAttribute.match(/none/))
    _bCustomAspectRatio = true;

  OnResize();
]]>
</script>
